cd "C:\Users\David\Dropbox\My Work Documents\Abortion Conjoint\REPLICATION ARCHIVE"

***GSS ABORTION ATTITUDES 
clear all
set matsize 4000
set maxvar 20000
set more 1

*2016 for comparison to 2018
use "GSS2016.dta", clear
include "gss_demographics.do"

//SAMPLE RESTRICTION
reg female r_white r_black r_hispanic r_other age partyid ideology relig 
keep if e(sample)
label var partyid "Party Identification (-3 = Str. Dem.; 3 = Str. Rep)"
estpost summarize age female r_white r_black r_hispanic r_other educ relig_att partyid ideology abany abpoor abnomore absingle abdefect abrape abhlth [aw=wtssall] 
eststo gss2016, title("2016 GSS")

rename abany ab_reason_1
rename abpoor ab_reason_2 
rename abnomore ab_reason_3
rename absingle ab_reason_4 
rename abdefect ab_reason_5
rename abrape ab_reason_6
rename abhlth ab_reason_7
gen abortion=ab_reason_2+ab_reason_3+ab_reason_4+ab_reason_5+ab_reason_6+ab_reason_6
reg abortion age female r_black r_hispanic r_other educ relig_att partyid ideology [aw=wtssall] , r
eststo gss_reg_2016, title("GSS 2016")

***GSS ABORTION ATTITUDES
use "GSS2018.dta", clear
include "gss_demographics.do"

//SAMPLE RESTRICTION
reg female r_white r_black r_hispanic r_other age partyid ideology relig 
keep if e(sample)
label var partyid "Party Identification (-3 = Str. Dem.; 3 = Str. Rep)"
estpost summarize age female r_white r_black r_hispanic r_other educ relig_att partyid ideology abany abpoor abnomore absingle abdefect abrape abhlth [aw=wtssall] 
eststo gss, title("2018 GSS")

rename abany ab_reason_1
rename abpoor ab_reason_2 
rename abnomore ab_reason_3
rename absingle ab_reason_4 
rename abdefect ab_reason_5
rename abrape ab_reason_6
rename abhlth ab_reason_7
gen abortion=ab_reason_2+ab_reason_3+ab_reason_4+ab_reason_5+ab_reason_6+ab_reason_6
reg abortion age female r_black r_hispanic r_other educ relig_att partyid ideology [aw=wtssall] , r
eststo gss_reg, title("GSS 2018")

***CONJOINT DATA
use "conjoint_data.dta", clear
label var partyid "Party Identification (-3 = Str. Dem.; 3 = Str. Rep)"
cd tables

* Number in experimental branch completed at least one task
egen completed=rownonmiss(ab_choice_*)
tab completed study2 if gss==0

******OUTPUT SUMMARY STATISTICS (TABLE A1) ************
estpost summarize age female r_white r_black r_hispanic r_other educ relig_att partyid ideology abany abnobc abbcfail abpoor abnomore absingle abdefect abrape abhlth
eststo pooled, title("Studies 1 and 2 (pooled)")

estpost summarize age female r_white r_black r_hispanic r_other educ relig_att partyid ideology abany abnobc abbcfail abpoor abnomore absingle abdefect abrape abhlth if study2==0  
eststo study_1, title("Study 1")

estpost summarize age female r_white r_black r_hispanic r_other educ relig_att ideology partyid abany abnobc abbcfail abpoor abnomore absingle abdefect abrape abhlth if study2==1
eststo study_2, title("Study 2")
esttab gss2016 gss pooled study_1 study_2 using "Table_A1.tex", cells(mean(fmt(a2)) sd(par fmt(a2))) replace nogaps booktabs wrap varwidth(40) nonotes nodepvars label longtable fragment

****** Observational data regressions specifying 6-point GSS scale as outcome (Table A5)***
gen abortion=abpoor+abnomore+absingle+abdefect+abrape+abhlth 
reg abortion age female r_black r_hispanic r_other educ relig_att partyid ideology, r
eststo orig_survey_reg, title("Original Survey (Pooled)")
esttab gss_reg_2016 gss_reg orig_survey_reg using Table_A5.tex, replace nogaps booktabs wrap varwidth(100) b(%9.3f) se(%9.3f) star(* 0.05 ** .01) longtable nonotes  label nodepvars fragment nobaselevels 

***********RESHAPE FOR CONJOINT ANALYSIS
reshape long ab_choice_ ab_conjoint_name_ ab_income_ ab_marital_ ab_children_ ab_reason_ ab_weeks_ ab_age_ time_ab_conj_, i(responseid) j(task)
gen conj_time=ln(time_ab_conj_)
destring ab_age_ , replace
recode ab_age_ (14/17=1) (18/29=2) (30/39=3) (40/50=4), gen(ab_age)
drop ab_age_
tab ab_age, gen(ab_age_)
drop ab_age_1 
gen zero_age=0
label var zero_age "Age 14-17"
label var ab_age_2 "Age 18-29"
label var ab_age_3 "Age 30-39"
label var ab_age_4 "Age 40-50"
replace ab_income_=subinstr(ab_income_,",","",.)
replace ab_income_=subinstr(ab_income_,"$","",.)
destring ab_income_, replace 
recode ab_income (0/25600=1) (25601/50000=2) (50001/79542=3) (79543/130000=4) (130001/1000000=5), gen(ab_inc_quin)
tab ab_inc_quin, gen(ab_inc_quin_)
drop ab_inc_quin_1 
gen zero_inc=0
label var zero_inc "Income Quintile 1"
label var ab_inc_quin_2 "Income Quintile 2"
label var ab_inc_quin_3 "Income Quintile 3"
label var ab_inc_quin_4 "Income Quintile 4"
label var ab_inc_quin_5 "Income Quintile 5"

destring ab_weeks, replace
label var ab_weeks "Weeks into Pregnancy"
recode ab_weeks (0/12=1) (13/26=2) (27/40=3) (*=.), gen(ab_trimester)
tab ab_trimester, gen(ab_trimester_)
rename ab_trimester_1 trimester_1
label var trimester_1 "First Trimester"
gen zero_trimester=0
label var zero_trimester "First Trimester"
label var ab_trimester_2 "Second Trimester"
label var ab_trimester_3 "Third Trimester"

destring ab_children_, replace
label var ab_children_ "Number of Children"
tab ab_children, gen(ab_child_)
drop ab_child_1 
gen zero_child=0
label var zero_child "No children" 
label var ab_child_2 "Has 1 Child"
label var ab_child_3 "Has 2 Children"
label var ab_child_4 "Has 3 Children"
label var ab_child_5 "Has 4 Children"

tab ab_marital, gen(marital_)
drop ab_marital
drop marital_2 
gen zero_marital=0
rename marital_1 ab_marital
label var zero_marital "Not Married"
label var ab_marital "Married"
tab ab_reason, gen(reason_)
drop ab_reason
rename reason_1 ab_reason_rape
rename reason_2 ab_reason_nobc
rename reason_3 X_ab_reason_none
gen zero_reason=0
rename reason_4 ab_reason_defect
rename reason_5 ab_reason_bcfail
rename reason_6 ab_reason_womanhealth
label var zero_reason "No specific reason"
label var ab_reason_rape "Rape"
label var ab_reason_nobc "No birth control"
label var ab_reason_defect "Serious birth defect"
label var ab_reason_bcfail "Birth control failed"
label var ab_reason_womanhealth "Woman's health"

***names
*Race/Ethnicity
gen race_1=.
gen race_2=.
replace race_1=1 if ab_conjoint_name=="Abigail Smith"
replace race_1=2 if ab_conjoint_name=="Alaliyah Booker"
replace race_1=1 if ab_conjoint_name=="Alexus Banks"
replace race_1=1 if ab_conjoint_name=="Allison Nelson"
replace race_1=1 if ab_conjoint_name=="Amy Mueller"
replace race_1=1 if ab_conjoint_name=="Anne Evans"
replace race_1=3 if ab_conjoint_name=="Beatriz Ibarra"
replace race_1=3 if ab_conjoint_name=="Beatriz Martinez"
replace race_1=3 if ab_conjoint_name=="Blanca Ramirez"
replace race_1=1 if ab_conjoint_name=="Caitlin Schneider"
replace race_1=3 if ab_conjoint_name=="Carlita Torres"
replace race_1=1 if ab_conjoint_name=="Carly Smith"
replace race_1=3 if ab_conjoint_name=="Carmela Velazquez"
replace race_1=3 if ab_conjoint_name=="Carmen Barajas"
replace race_1=3 if ab_conjoint_name=="Carmen Lopez"
replace race_1=3 if ab_conjoint_name=="Carola Huerta"
replace race_1=3 if ab_conjoint_name=="Carola Ibarra"
replace race_1=1 if ab_conjoint_name=="Carrie King"
replace race_1=3 if ab_conjoint_name=="Catalina Hernandez"
replace race_1=3 if ab_conjoint_name=="Catalina Jaurez"
replace race_1=1 if ab_conjoint_name=="Claire Schwartz"
replace race_1=2 if ab_conjoint_name=="Deja Jefferson"
replace race_1=2 if ab_conjoint_name=="Deja Mosley"
replace race_1=3 if ab_conjoint_name=="Dolores Ramirez"
replace race_1=3 if ab_conjoint_name=="Dolores Sanchez"
replace race_1=3 if ab_conjoint_name=="Dominique Mosley"
replace race_1=2 if ab_conjoint_name=="Ebony Mosley"
replace race_1=2 if ab_conjoint_name=="Ebony Washington"
replace race_1=1 if ab_conjoint_name=="Emily Schmidt"
replace race_1=1 if ab_conjoint_name=="Emma Clark"
replace race_1=1 if ab_conjoint_name=="Hannah Phillips"
replace race_1=1 if ab_conjoint_name=="Heather Martin"
replace race_1=1 if ab_conjoint_name=="Holly Schroeder"
replace race_1=2 if ab_conjoint_name=="Jada Mosley"
replace race_1=2 if ab_conjoint_name=="Jasmin Jefferson"
replace race_1=2 if ab_conjoint_name=="Jasmine Joseph"
replace race_1=2 if ab_conjoint_name=="Jazmine Jefferson"
replace race_1=1 if ab_conjoint_name=="Jenna Anderson"
replace race_1=1 if ab_conjoint_name=="Jill Smith"
replace race_1=1 if ab_conjoint_name=="Katelyn Miller"
replace race_1=1 if ab_conjoint_name=="Katherine Adams"
replace race_1=1 if ab_conjoint_name=="Kathryn Evans"
replace race_1=1 if ab_conjoint_name=="Katie Novak"
replace race_1=2 if ab_conjoint_name=="Keisha Rivers"
replace race_1=2 if ab_conjoint_name=="Kiara Jackson"
replace race_1=1 if ab_conjoint_name=="Kristen Clark"
replace race_1=2 if ab_conjoint_name=="Latonya Rivers"
replace race_1=2 if ab_conjoint_name=="Latoya Rivers"
replace race_1=1 if ab_conjoint_name=="Madeline Haas"
replace race_1=3 if ab_conjoint_name=="Magdalena Perez"
replace race_1=3 if ab_conjoint_name=="Margarita Garcia"
replace race_1=3 if ab_conjoint_name=="Margarita Velazquez"
replace race_1=3 if ab_conjoint_name=="Maria Ramirez"
replace race_1=3 if ab_conjoint_name=="Maria Rodriguez"
replace race_1=1 if ab_conjoint_name=="Molly Kruger"
replace race_1=2 if ab_conjoint_name=="Precious Washington"
replace race_1=2 if ab_conjoint_name=="Raven Korsey"
replace race_1=3 if ab_conjoint_name=="Rosa Orozco"
replace race_1=3 if ab_conjoint_name=="Rosa Perez"
replace race_1=1 if ab_conjoint_name=="Sarah Miller"
replace race_1=2 if ab_conjoint_name=="Shanice Booker"
replace race_1=3 if ab_conjoint_name=="Teresa Jaurez"
drop if ab_choice==.

//TIDY DATA, KEEP ONLY NEEDED VARIABLES
keep ab_choice zero_* ab_weeks ab_trimester* trimester_1 ab_income ab_inc_quin* ab_marital ab_reason* X_ab_reason_none ab_age  ab_age_* ab_child_* race_1 female r_white r_black r_hispanic r_other age partyid ideology relig responseid conj_time time_ab_conj_  study2
replace race_1=0 if race_1==.
tab race_1, gen(ab_race_)
rename ab_race_2 white_profile 
gen zero_race=0
label var zero_race "White"
label var ab_race_1 "Study 1"
label var ab_race_3 "Black"
label var ab_race_4 "Latina"

recode partyid (-3/-1=1) (0=2) (1/3=3), gen(pid3)
label var pid3 "Party ID (1 = Dem; 2 = Ind.; 3 = Rep.)"

***MAIN FX FIGURE
reg ab_choice zero_reason ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman zero_trimester ab_trimester_* zero_inc ab_inc_quin_* zero_marital ab_marital zero_age ab_age_* zero_child ab_child_*  ab_race_1 zero_race  ab_race_3 ab_race_4 female r_black r_hispanic r_other age ideology partyid relig , cluster(responseid)
eststo direct_FX, title("Conjoint")
coefplot (direct_FX, msymbol(Oh) connect(none) mcolor(black)  msize(vsmall) ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label (Pooled)) , omitted xline(0, lcolor(black)) level(95) xtitle("Estimated Effect on Probability Supporting Abortion",  size(vsmall))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) xlabel(-.2(.1).3, labsize(vsmall)) xscale(lw(none))  legend(off) coeflabels(,wrap(40)) drop(_cons) ysize(6) ylabel(,labsize(vsmall)) headings(zero_reason = "{bf:Reason}"  zero_trimester = "{bf:Trimester}" zero_inc = "{bf:Family Income}" zero_marital = "{bf:Marital Status}" zero_age = "{bf:Age}" zero_child = "{bf:Number of Children}" ab_race_1 = "{bf:Race / Ethnicity}", labsize(vsmall)) keep(zero_reason ab_reason* zero_trimester ab_trimester* zero_inc ab_inc_quin* zero_marital ab_marital zero_age ab_age_* zero_child ab_child_*  ab_race_1  zero_race ab_race_3 ab_race_4 )
graph export "Figure_2.eps", as(eps) replace
*Joint Sig Tests
test ab_reason_defect==ab_reason_rape 
test ab_reason_defect==ab_reason_woman 
test ab_reason_rape==ab_reason_woman 

test ab_trimester_2 ab_trimester_3
test ab_inc_quin_2 ab_inc_quin_3 ab_inc_quin_4 ab_inc_quin_5
test ab_inc_quin_3 
test ab_marital 
test ab_age_2 ab_age_3 ab_age_4
test ab_child_2 ab_child_3 ab_child_4
test ab_race_1 ab_race_3 ab_race_4 
test ab_race_1==ab_race_3
test ab_race_1==ab_race_4 
test ab_race_3==ab_race_4 


**OUTPUT REGRESSIONS
label var ab_race_1 "Study 1"
label var ab_race_3 "Pregnant Woman: Black" 
label var ab_race_4 "Pregnant Woman: Latina"

reg ab_choice ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman ab_trimester_* ab_inc_quin_* ab_marital ab_age_* ab_child_*  ab_race_1 ab_race_3 ab_race_4 female r_black r_hispanic r_other age ideology partyid relig, cluster(responseid)
eststo pooled, title("Pooled")
reg ab_choice ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman ab_trimester_* ab_inc_quin_* ab_marital ab_age_* ab_child_* female r_black r_hispanic r_other age ideology partyid relig if study2==0, cluster(responseid)
eststo study1, title("Study 1")
reg ab_choice ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman ab_trimester_* ab_inc_quin_* ab_marital ab_age_* ab_child_*  ab_race_3 ab_race_4 female r_black r_hispanic r_other age ideology partyid relig if study2==1, cluster(responseid)
eststo study2, title("Study 2")
esttab pooled study1 study2 using Table_A2.tex, replace nogaps booktabs wrap varwidth(40) b(%9.3f) se(%9.3f) star(* 0.05 ** .01) longtable nonotes  label nodepvars fragment
**note, no sig difference in FX across studies
reg ab_choice (ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman ab_trimester_* ab_inc_quin_* ab_marital ab_age_* ab_child_*)##study2 ab_race_1 ab_race_3 ab_race_4 female r_black r_hispanic r_other age ideology partyid relig , cluster(responseid)


**TIMING INTERACTION
label var X_ab_reason_none "No reason specified"

reg ab_choice X_ab_reason_n ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman if trimester_1, nocons cluster(responseid)
eststo trimester_1, title("Trimester 1")
reg ab_choice X_ab_reason_n ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman if ab_trimester_2, nocons cluster(responseid)
eststo trimester_2, title("Trimester 2")
reg ab_choice X_ab_reason_n ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman if ab_trimester_3, nocons cluster(responseid)
eststo trimester_3, title("Trimester 3")
coefplot (trimester_1, msymbol(Oh) connect(none) mcolor(black)  msize(small) ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label (Trimester 1))  (trimester_2, msymbol(Oh) connect(none) mcolor(gs8)  msize(small) ciopts(lcolor(gs8) lwidth(thin) msize(vtiny)) label (Trimester 2))  (trimester_3, msymbol(Oh) connect(none) mcolor(gs12)  msize(small) ciopts(lcolor(gs12) lwidth(thin) msize(vtiny)) label (Trimester 3)) , level(95) xtitle("Estimated Probability of Supporting Abortion",  size(small))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) xlabel(0(.1)1, labsize(small)) xscale(lw(none))  legend(off)  ylabel(,labsize(small))  text(.75 .74 "Trimester 1",size(small)) text(1 .57 "Trimester 2",size(small) color(gs4)) text(1.25 .215 "Trimester 3",size(small) color(gs8))
graph export "Figure_4.eps", as(eps) replace

reg ab_choice (ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman ab_inc_quin_* ab_marital ab_age_* ab_child_*  ab_race_1 ab_race_3 ab_race_4)##(ab_trimester_2 ab_trimester_3) female r_black r_hispanic r_other age ideology partyid relig, cluster(responseid)
eststo reason_trimester
esttab reason_trimester using Table_A4.tex, replace nogaps booktabs wrap varwidth(100) b(%9.3f) se(%9.3f) star(* 0.05 ** .01) drop(female r_black r_hispanic r_other age ideology partyid relig_att) longtable nonotes  label nodepvars fragment nobaselevels interaction(" x ")

****************************
** FX BY GROUP *************
****************************
*conjoint
reg ab_choice zero_reason ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman zero_trimester ab_trimester_* zero_inc ab_inc_quin_* zero_marital ab_marital zero_age ab_age_* zero_child ab_child_*  ab_race_1 zero_race ab_race_3 ab_race_4 female r_black r_hispanic r_other age ideology relig if pid3==1, cluster(responseid)
eststo fx_democrats, title("Democrats")
reg ab_choice zero_reason ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman zero_trimester ab_trimester_* zero_inc ab_inc_quin_* zero_marital ab_marital zero_age ab_age_* zero_child ab_child_*  ab_race_1 zero_race ab_race_3 ab_race_4 female r_black r_hispanic r_other age ideology relig if pid3==3, cluster(responseid)
eststo fx_republicans, title("Republicans")

coefplot (fx_democrats, msymbol(O) connect(none) mcolor(black)  msize(vsmall) ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label (Democrats)) (fx_republicans, msymbol(Oh) connect(none) mcolor(gs10)  msize(vsmall) ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label (Republicans)) , omitted xline(0, lcolor(black)) level(95) xtitle("Estimated Effect on Probability Supporting Abortion",  size(vsmall))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) xlabel(-.3(.1).3, labsize(vsmall)) xscale(lw(none))  legend(off) coeflabels(,wrap(40)) drop(_cons) ysize(6) ylabel(,labsize(vsmall)) headings(zero_reason = "{bf:Reason}"  zero_trimester = "{bf:Trimester}" zero_inc = "{bf:Family Income}" zero_marital = "{bf:Marital Status}" zero_age = "{bf:Age}" zero_child = "{bf:Number of Children}" ab_race_1 = "{bf:Race / Ethnicity}", labsize(vsmall)) keep(zero_reason ab_reason* zero_trimester ab_trimester* zero_inc ab_inc_quin* zero_marital ab_marital zero_age ab_age_* zero_child ab_child_*  ab_race_1 zero_race  ab_race_3 ab_race_4 ) text(1.7 -.07 "Democrats",size(vsmall) color(black)) text(2.20 .075 "Republicans",size(vsmall) color(gs8))
graph export "Figure_A1.eps", as(eps) replace


//PID moderation check
reg ab_choice (ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman ab_trimester_* ab_inc_quin_* ab_marital ab_age_* ab_child_*  ab_race_1 ab_race_3 ab_race_4)##i.pid3  female r_black r_hispanic r_other c.age c.ideology c.relig, cluster(responseid)

*** BY GENDER
reg ab_choice zero_reason ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman zero_trimester ab_trimester_* zero_inc ab_inc_quin_* zero_marital ab_marital zero_age ab_age_* zero_child ab_child_*  ab_race_1 zero_race ab_race_3 ab_race_4 r_black r_hispanic r_other age ideology partyid relig if female==0, cluster(responseid)
eststo fx_male, title("Male")
reg ab_choice zero_reason ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman zero_trimester ab_trimester_* zero_inc ab_inc_quin_* zero_marital ab_marital zero_age ab_age_* zero_child ab_child_*  ab_race_1 zero_race ab_race_3 ab_race_4 r_black r_hispanic r_other age ideology partyid relig if female==1, cluster(responseid)
eststo fx_female, title("Female")

coefplot (fx_male, msymbol(O) connect(none) mcolor(black)  msize(vsmall) ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label (Male Respondents)) (fx_female, msymbol(Oh) connect(none) mcolor(gs10)  msize(vsmall) ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label (Female Respondents)) , omitted xline(0, lcolor(black)) level(95) xtitle("Estimated Effect on Probability Supporting Abortion",  size(vsmall))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) xlabel(-.3(.1).3, labsize(vsmall)) xscale(lw(none))  legend(off) coeflabels(,wrap(40)) drop(_cons) ysize(6) ylabel(,labsize(vsmall)) headings(zero_reason = "{bf:Reason}"  zero_trimester = "{bf:Trimester}" zero_inc = "{bf:Family Income}" zero_marital = "{bf:Marital Status}" zero_age = "{bf:Age}" zero_child = "{bf:Number of Children}" ab_race_1 = "{bf:Race / Ethnicity}", labsize(vsmall)) keep(zero_reason ab_reason* zero_trimester ab_trimester* zero_inc ab_inc_quin* zero_marital ab_marital zero_age ab_age_* zero_child ab_child_*  ab_race_1 zero_race ab_race_3 ab_race_4 ) text(1.7 -.105 "Male Respondents",size(vsmall) color(black)) text(2.20 .115 "Female Respondents",size(vsmall) color(gs8))
graph export "Figure_A2.eps", as(eps) replace

//Gender moderation check
reg ab_choice (ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman ab_trimester_* ab_inc_quin_* ab_marital ab_age_* ab_child_*  ab_race_1 ab_race_3 ab_race_4)##i.female , cluster(responseid)

******MARGINAL MEANS BY GROUP (PID; GENDER)**********
reg ab_choice X_ab_reason_none ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman if female==0, nocons cluster(responseid)
eststo reason_fx_male, title("Men")
reg ab_choice X_ab_reason_none ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman if female==1, nocons cluster(responseid)
eststo reason_fx_female, title("Women")
reg ab_choice X_ab_reason_none ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman if pid==1, nocons cluster(responseid)
eststo reason_fx_dem, title("Democrats")
reg ab_choice X_ab_reason_none ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman if pid==3, nocons cluster(responseid)
eststo reason_fx_rep, title("Republicans")
reg ab_choice trimester_1 ab_trimester_2 ab_trimester_3 if female==0, nocons cluster(responseid)
eststo timing_fx_male, title("Men")
reg ab_choice trimester_1 ab_trimester_2 ab_trimester_3 if female==1, nocons cluster(responseid)
eststo timing_fx_female, title("Women")
reg ab_choice trimester_1 ab_trimester_2 ab_trimester_3 if pid==1, nocons cluster(responseid)
eststo timing_fx_dem, title("Democrats")
reg ab_choice trimester_1 ab_trimester_2 ab_trimester_3 if pid==3, nocons cluster(responseid)
eststo timing_fx_rep, title("Republicans")

coefplot (reason_fx_dem, msymbol(O) connect(none) mcolor(black)  msize(vsmall) ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label (Democratic Respondents)) (reason_fx_rep, msymbol(Oh) connect(none) mcolor(gs10)  msize(vsmall) ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label (Republican Respondents))  (timing_fx_dem, msymbol(O) connect(none) mcolor(black)  msize(vsmall) ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label (Democratic Respondents)) (timing_fx_rep, msymbol(Oh) connect(none) mcolor(gs10)  msize(vsmall) ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label (Republican Respondents)) , level(95) xtitle("Estimated Probability of Supporting Abortion",  size(vsmall))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) xlabel(0(.1)1, labsize(vsmall)) xscale(lw(none))  legend(off) coeflabels(,wrap(40)) ylabel(,labsize(vsmall)) text(2.2 .7 "Democratic Respondents",size(vsmall) color(black))  text(1.8 .175 "Republican Respondents",size(vsmall) color(gs8)) offset(0)  headings(X_ab_reason_none = "{bf:Reason}"  trimester_1 = "{bf:Trimester}", labsize(vsmall))
graph export "Figure_5.eps", as(eps) replace

coefplot (reason_fx_male, msymbol(O) connect(none) mcolor(black)  msize(vsmall) ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label (Male Respondents)) (reason_fx_female, msymbol(Oh) connect(none) mcolor(gs10)  msize(vsmall) ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label (Female Respondents))  (timing_fx_male, msymbol(O) connect(none) mcolor(black)  msize(vsmall) ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label (Male Respondents)) (timing_fx_female, msymbol(Oh) connect(none) mcolor(gs10)  msize(vsmall) ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label (Female Respondents)) , level(95) xtitle("Estimated Probability of Supporting Abortion",  size(vsmall))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) xlabel(0(.1)1, labsize(vsmall)) xscale(lw(none))  legend(off) coeflabels(,wrap(40)) ylabel(,labsize(vsmall)) text(2.2 .58 "Male Respondents",size(vsmall) color(black))  text(1.8 .335 "Female Respondents",size(vsmall) color(gs8)) offset(0) headings(X_ab_reason_none = "{bf:Reason}"  trimester_1 = "{bf:Trimester}", labsize(vsmall))
graph export "Figure_6.eps", as(eps) replace


*****LOWESS TIMING RELATIONSHIPS*****
reg ab_choice trimester_1 ab_trimester_* , nocons cluster(responseid)
eststo timing_FX
coefplot (timing_FX, msymbol(Oh) connect(none) mcolor(black)  msize(vsmall) ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label (Pooled)) , omitted level(95) ytitle("Estimated Probability of Supporting Abortion")  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  legend(off) coeflabels(,wrap(40)) drop(_cons) ylabel(.4(.1).8)   keep(trimester_1 ab_trimester*) vertical nodrop  addplot(lowess ab_choice ab_weeks, xaxis(2) lcolor(black)||lfit ab_choice ab_weeks, xaxis(2) lcolor(black) lpattern(dash)) xlabel(4(4)36, axis(2)) 
graph export "Figure_3.eps", as(eps) replace
**indicators better?
tab ab_weeks, gen(WEEKS_)
drop WEEKS_1 WEEKS_2
reg ab_choice ab_weeks WEEKS_*, cluster(responseid)
test WEEKS_3	WEEKS_4	WEEKS_5	WEEKS_6	WEEKS_7	WEEKS_8	WEEKS_9	WEEKS_10	WEEKS_11	WEEKS_12	WEEKS_13	WEEKS_14	WEEKS_15	WEEKS_16	WEEKS_17	WEEKS_18	WEEKS_19	WEEKS_20	WEEKS_21	WEEKS_22	WEEKS_23	WEEKS_24	WEEKS_25	WEEKS_26	WEEKS_27	WEEKS_28	WEEKS_29	WEEKS_30	WEEKS_31	WEEKS_32	WEEKS_33
drop WEEKS*
reg ab_choice c.ab_weeks##c.ab_weeks, cluster(responseid)
reg ab_choice c.ab_weeks##c.ab_weeks##c.ab_weeks, cluster(responseid)

*by party
twoway (lowess ab_choice ab_weeks_ if pid3==1, lcolor(black) lpattern(solid) lwidth(thick)) (lfit ab_choice ab_weeks_ if pid3==1, lcolor(black) lpattern(solid) lwidth(thin)) (lowess ab_choice ab_weeks_ if pid3==3, lcolor(black) lpattern(shortdash) lwidth(thick)) (lfit ab_choice ab_weeks_ if pid3==3, lcolor(black) lpattern(solid) lwidth(thin)), ytitle("Estimated Probability of Supporting Abortion")  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  legend(region(lcolor(white))  cols(2)  order(1 "Democrats" 3 "Republicans"))  ylabel(.3(.1).8) 
graph export "Figure_A3.eps", as(eps) replace

*by gender
twoway (lowess ab_choice ab_weeks_ if female==0, lcolor(black) lpattern(solid) lwidth(thick)) (lfit ab_choice ab_weeks_ if female==0, lcolor(black) lpattern(solid) lwidth(thin)) (lowess ab_choice ab_weeks_ if female==1, lcolor(black) lpattern(shortdash) lwidth(thick)) (lfit ab_choice ab_weeks_ if female==1, lcolor(black) lpattern(solid) lwidth(thin)), ytitle("Estimated Probability of Supporting Abortion")  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  legend(region(lcolor(white))  cols(2)  order(1 "Male Respondents" 3 "Female Respondents"))  ylabel(.3(.1).8) 
graph export "Figure_A4.eps", as(eps) replace


****RACE/ETHNICITY PROBE (Discussion Section)
reg ab_choice zero_reason ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman zero_trimester ab_trimester_* zero_inc ab_inc_quin_* zero_marital ab_marital zero_age ab_age_* zero_child ab_child_*  ab_race_1 zero_race  ab_race_3 ab_race_4 female age ideology partyid relig if r_white==1, cluster(responseid)
eststo fx_white, title("White")
reg ab_choice zero_reason ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman zero_trimester ab_trimester_* zero_inc ab_inc_quin_* zero_marital ab_marital zero_age ab_age_* zero_child ab_child_*  ab_race_1 zero_race  ab_race_3 ab_race_4 female age ideology partyid relig if r_black==1, cluster(responseid)
eststo fx_black, title("Black")
reg ab_choice zero_reason ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman zero_trimester ab_trimester_* zero_inc ab_inc_quin_* zero_marital ab_marital zero_age ab_age_* zero_child ab_child_*  ab_race_1 zero_race  ab_race_3 ab_race_4 female age ideology partyid relig if r_hisp==1, cluster(responseid)
eststo fx_hisp, title("Hispanic")
coefplot (fx_white, msymbol(O) connect(none) mcolor(black)  msize(vsmall) ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label (White)) (fx_black, msymbol(Oh) connect(none) mcolor(gs6)  msize(vsmall) ciopts(lcolor(gs6) lwidth(thin) msize(vtiny)) label (Black)) (fx_hisp, msymbol(Oh) connect(none) mcolor(gs10)  msize(vsmall) ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label (Latinx)) , omitted xline(0, lcolor(black)) level(95) xtitle("Estimated Effect on Probability Supporting Abortion",  size(vsmall))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) xlabel(-.2(.1).2, labsize(vsmall)) xscale(lw(none))  legend(off) coeflabels(,wrap(40)) drop(_cons) ylabel(,labsize(vsmall))  keep(ab_race_3 ab_race_4) text(1.7 .06 "White Respondents",size(vsmall) color(black)) text(1.95 -.07 "Black Respondents",size(vsmall) color(gs6)) text(2.2 .1411575 "Latinx Respondents",size(vsmall) color(gs10)) text(.7 .06 "White Respondents",size(vsmall) color(black)) text(.95 -.07 "Black Respondents",size(vsmall) color(gs6)) text(1.2 .1411575 "Latinx Respondents",size(vsmall) color(gs10))
graph export "Figure_A5.eps", as(eps) replace

reg ab_choice (zero_reason ab_reason_nobc ab_reason_bcf ab_reason_defect ab_reason_rape ab_reason_woman zero_trimester ab_trimester_* zero_inc ab_inc_quin_* zero_marital ab_marital zero_age ab_age_* zero_child ab_child_*  ab_race_1 zero_race  ab_race_3 ab_race_4 female c.age c.ideology c.partyid c.relig)##(r_black r_hisp r_other), cluster(responseid)
test 1.ab_race_3#1.r_black
test 1.ab_race_4#1.r_black
test 1.ab_race_3#1.r_hisp
test 1.ab_race_4#1.r_hisp
